using System;
using System.Runtime.InteropServices;

namespace LibVlc
{
	public delegate void cb(IntPtr data);

	public class Instance : Object
	{
		[DllImport("vlc")]
		static extern IntPtr libvlc_new(int argc,[MarshalAs(UnmanagedType.LPArray)] string[] argv);
		[DllImport("vlc")]
		static extern void libvlc_release(IntPtr instance);
		[DllImport("vlc")]
		static extern int libvlc_add_intf(IntPtr instance,[MarshalAs(UnmanagedType.LPTStr)] string name);
		[DllImport("vlc")]
		static extern void libvlc_set_exit_handler(IntPtr instance, cb func, IntPtr opaque);
		[DllImport("vlc")]
		static extern void libvlc_wait(IntPtr instance);
		[DllImport("vlc")]
		static extern void libvlc_set_user_agent(
			IntPtr instance,
			[MarshalAs(UnmanagedType.LPStr)]string name,
			[MarshalAs(UnmanagedType.LPStr)]string http);
		[DllImport("vlc")]
		static extern IntPtr libvlc_audio_filter_list_get(IntPtr instance);
		[DllImport("vlc")]
		static extern IntPtr libvlc_video_filter_list_get(IntPtr instance);

		public Instance (int argc, string[] argv) : base(libvlc_new (argc,argv))
		{
		}
		public Instance (string[] argv) : this(argv.Length,argv)
		{
		}
		public Instance () : this(new string[0])
		{}
		~Instance(){libvlc_release (this.Handle);}

		public bool AddInterface(string name){
			return (libvlc_add_intf (Handle,name)==0)?true:false;
		}
		public void SetExitHandler(cb func){
			libvlc_set_exit_handler (Handle,func,IntPtr.Zero);
		}
		public void Wait(){libvlc_wait (Handle);}
		public void SetUserAgent(string name, string http){
			libvlc_set_user_agent (Handle,name,http);
		}
		public ModuleDescription AudioFilterList{
			get{
				return new ModuleDescription(libvlc_audio_filter_list_get (Handle));
			}
		}
		public ModuleDescription VideoFilterList{
			get{
				return new ModuleDescription(libvlc_video_filter_list_get (Handle));
			}
		}
	
	}
}

